pub struct ConfigInit {
pub data: ConfigParams,
}Fields
data: ConfigParamsTrait Implementations
Sourceimpl ArrangeAccounts for ConfigInit
impl ArrangeAccounts for ConfigInit
type ArrangedAccounts = ConfigInitInstructionAccounts
fn arrange_accounts(accounts: &[AccountMeta]) -> Option<Self::ArrangedAccounts>
Sourceimpl BorshDeserialize for ConfigInitwhere
ConfigParams: BorshDeserialize,
impl BorshDeserialize for ConfigInitwhere
ConfigParams: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl CarbonDeserialize for ConfigInit
impl CarbonDeserialize for ConfigInit
const DISCRIMINATOR: &'static [u8]
fn deserialize(data: &[u8]) -> Option<Self>
Sourceimpl Clone for ConfigInit
impl Clone for ConfigInit
Sourcefn clone(&self) -> ConfigInit
fn clone(&self) -> ConfigInit
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ConfigInit
impl Debug for ConfigInit
Sourceimpl<'de> Deserialize<'de> for ConfigInit
impl<'de> Deserialize<'de> for ConfigInit
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for ConfigInit
impl Hash for ConfigInit
Sourceimpl PartialEq for ConfigInit
impl PartialEq for ConfigInit
Sourceimpl Serialize for ConfigInit
impl Serialize for ConfigInit
impl Eq for ConfigInit
impl StructuralPartialEq for ConfigInit