pub struct ConfigUpdate {
pub data: ConfigParams,
}Fields
data: ConfigParamsTrait Implementations
Sourceimpl ArrangeAccounts for ConfigUpdate
impl ArrangeAccounts for ConfigUpdate
type ArrangedAccounts = ConfigUpdateInstructionAccounts
fn arrange_accounts(accounts: &[AccountMeta]) -> Option<Self::ArrangedAccounts>
Sourceimpl BorshDeserialize for ConfigUpdatewhere
ConfigParams: BorshDeserialize,
impl BorshDeserialize for ConfigUpdatewhere
ConfigParams: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl CarbonDeserialize for ConfigUpdate
impl CarbonDeserialize for ConfigUpdate
const DISCRIMINATOR: &'static [u8]
fn deserialize(data: &[u8]) -> Option<Self>
Sourceimpl Clone for ConfigUpdate
impl Clone for ConfigUpdate
Sourcefn clone(&self) -> ConfigUpdate
fn clone(&self) -> ConfigUpdate
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ConfigUpdate
impl Debug for ConfigUpdate
Sourceimpl<'de> Deserialize<'de> for ConfigUpdate
impl<'de> Deserialize<'de> for ConfigUpdate
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for ConfigUpdate
impl Hash for ConfigUpdate
Sourceimpl PartialEq for ConfigUpdate
impl PartialEq for ConfigUpdate
Sourceimpl Serialize for ConfigUpdate
impl Serialize for ConfigUpdate
impl Eq for ConfigUpdate
impl StructuralPartialEq for ConfigUpdate