pub struct MigrationEvent {
pub tokens_migrated: u64,
pub tokens_burned: u64,
pub collateral_migrated: u64,
pub fee: u64,
pub label: String,
}Fields
tokens_migrated: u64tokens_burned: u64collateral_migrated: u64fee: u64label: StringTrait Implementations
Sourceimpl BorshDeserialize for MigrationEvent
impl BorshDeserialize for MigrationEvent
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl CarbonDeserialize for MigrationEvent
impl CarbonDeserialize for MigrationEvent
const DISCRIMINATOR: &'static [u8]
fn deserialize(data: &[u8]) -> Option<Self>
Sourceimpl Clone for MigrationEvent
impl Clone for MigrationEvent
Sourcefn clone(&self) -> MigrationEvent
fn clone(&self) -> MigrationEvent
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MigrationEvent
impl Debug for MigrationEvent
Sourceimpl<'de> Deserialize<'de> for MigrationEvent
impl<'de> Deserialize<'de> for MigrationEvent
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for MigrationEvent
impl Hash for MigrationEvent
Sourceimpl PartialEq for MigrationEvent
impl PartialEq for MigrationEvent
Sourceimpl Serialize for MigrationEvent
impl Serialize for MigrationEvent
impl Eq for MigrationEvent
impl StructuralPartialEq for MigrationEvent